package com.ztmap.project.zhny.lotusxnyxnqk.service;

import java.util.List;
import com.ztmap.project.zhny.lotusxnyxnqk.domain.TLotusXnyxnqk;

/**
 * 新能源消纳情况Service接口
 * 
 * @author ztmap
 * @date 2023-11-16
 */
public interface ITLotusXnyxnqkService 
{
    /**
     * 查询新能源消纳情况
     * 
     * @param id 新能源消纳情况ID
     * @return 新能源消纳情况
     */
    public TLotusXnyxnqk selectTLotusXnyxnqkById(Long id);

    /**
     * 查询新能源消纳情况列表
     * 
     * @param tLotusXnyxnqk 新能源消纳情况
     * @return 新能源消纳情况集合
     */
    public List<TLotusXnyxnqk> selectTLotusXnyxnqkList(TLotusXnyxnqk tLotusXnyxnqk);

    /**
     * 新增新能源消纳情况
     * 
     * @param tLotusXnyxnqk 新能源消纳情况
     * @return 结果
     */
    public int insertTLotusXnyxnqk(TLotusXnyxnqk tLotusXnyxnqk);

    /**
     * 修改新能源消纳情况
     * 
     * @param tLotusXnyxnqk 新能源消纳情况
     * @return 结果
     */
    public int updateTLotusXnyxnqk(TLotusXnyxnqk tLotusXnyxnqk);

    /**
     * 批量删除新能源消纳情况
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTLotusXnyxnqkByIds(String ids);

    /**
     * 删除新能源消纳情况信息
     * 
     * @param id 新能源消纳情况ID
     * @return 结果
     */
    public int deleteTLotusXnyxnqkById(Long id);
}
